import React, { useState, useEffect, Suspense } from "react";
import {
  BrowserRouter as Router,
  Routes,
  Route,
  Outlet,
  useLocation,
  useNavigate,
  Link,
  Navigate,
} from "react-router-dom";
import Header from "./components/Header";
import Footer from "./components/Footer";
import MobileNavBar from "./components/MobileNavBar";
import { useMediaQuery } from "./hooks/useMediaQuery";
import { supabase, initSupabase } from "./lib/supabase";
import AuthModal from "./components/AuthModal";
import NewFilterModal from "./components/NewFilterModal";
import ProtectedRoute from "./components/ProtectedRoute";
import LoadingDots from "./components/LoadingDots";
import PageTitle from "./components/PageTitle";
import CheckoutPage from "./pages/CheckoutPage";
import "./i18n"; // Import i18n configuration
import "./App.css"; // Add global styles to prevent horizontal scrolling on mobile
import { AuthProvider } from "./contexts/AuthContext";
import HelpCenterPage from "./pages/HelpCenterPage";
import AccountHelpPage from "./pages/help/AccountHelpPage";
import BookingsHelpPage from "./pages/help/BookingsHelpPage";
import PaymentsHelpPage from "./pages/help/PaymentsHelpPage";
import SafetyHelpPage from "./pages/help/SafetyHelpPage";
import CommunicationHelpPage from "./pages/help/CommunicationHelpPage";
import PrivacyPolicyPage from "./pages/PrivacyPolicyPage";
import TermsOfServicePage from "./pages/TermsOfServicePage";
import { FilterOptions } from "./types";
import { cn } from "./lib/utils";
import { appInitializer, useAppInitialization } from "./lib/appInitializer";
import { initializePushNotifications } from "./services/pushNotificationService";
import HostDashboardRoute from "./components/HostDashboardRoute";
import { Toaster } from "react-hot-toast";
import { isOnListingWizardPage } from "./utils/navigation";

// Simplified AppInitializer component using centralized manager
const AppInitializer = () => {
  const initState = useAppInitialization();

  useEffect(() => {
    // Start initialization only once
    appInitializer.initialize();
  }, []);

  if (!initState.isComplete && initState.isInitializing) {
    return (
      <div className="flex items-center justify-center h-screen">
        <div className="text-center">
          <LoadingDots />
          <p className="mt-4 text-gray-600">
            {!initState.supabaseConnection && "Connecting to database..."}
            {initState.supabaseConnection &&
              !initState.currencySystem &&
              "Setting up currency system..."}
            {initState.supabaseConnection &&
              initState.currencySystem &&
              "Finalizing setup..."}
          </p>
        </div>
      </div>
    );
  }

  return null;
};

// Lazy load components
const ListingPage = React.lazy(() => import("./pages/ListingPage"));
const PropertyDetailPage = React.lazy(
  () => import("./pages/PropertyDetailPage")
);
const CreateListingPage = React.lazy(() => import("./pages/CreateListingPage"));
const EditListingPage = React.lazy(() => import("./pages/EditListingPage"));
const ManageListingsPage = React.lazy(
  () => import("./pages/ManageListingsPage")
);
const PropertyAvailabilityPage = React.lazy(
  () => import("./pages/PropertyAvailabilityPage")
);
const HostProfilePage = React.lazy(() => import("./pages/HostProfilePage"));
const ProfilePage = React.lazy(() => import("./pages/ProfilePage"));
const PaymentSetupPage = React.lazy(() => import("./pages/PaymentSetupPage"));
const StripeSetupPage = React.lazy(() => import("./pages/StripeSetupPage"));
const BookingsPage = React.lazy(() => import("./pages/BookingsPage"));
const WishlistsPage = React.lazy(() => import("./pages/WishlistsPage"));
const MessagesPage = React.lazy(() => import("./pages/MessagesPage"));
const NotificationsPage = React.lazy(() => import("./pages/NotificationsPage"));
const NotificationSettingsPage = React.lazy(
  () => import("./pages/NotificationSettingsPage")
);
const AdminPage = React.lazy(() => import("./pages/AdminPage"));
const AdminDashboardPage = React.lazy(
  () => import("./pages/AdminDashboardPage")
);
const AdminUsersPage = React.lazy(() => import("./pages/admin/AdminUsersPage"));
const AdminListingsPage = React.lazy(
  () => import("./pages/admin/AdminListingsPage")
);
const AdminBookingsPage = React.lazy(
  () => import("./pages/admin/AdminBookingsPage")
);
const AdminClaimsPage = React.lazy(
  () => import("./pages/admin/AdminClaimsPage")
);
const AdminBootstrapPage = React.lazy(
  () => import("./pages/admin/AdminBootstrapPage")
);
const AdminRevenuePage = React.lazy(
  () => import("./pages/admin/AdminRevenuePage")
);
const AdminSettingsPage = React.lazy(
  () => import("./pages/admin/AdminSettingsPage")
);
const AdminEmailsPage = React.lazy(
  () => import("./pages/admin/AdminEmailsPage")
);
const AdminStressTestPage = React.lazy(
  () => import("./pages/admin/AdminStressTestPage")
);
const AdminBookingStressTestPage = React.lazy(
  () => import("./pages/admin/AdminBookingStressTestPage")
);
const AdminMessageReportsPage = React.lazy(
  () => import("./pages/admin/AdminMessageReportsPage")
);

// Add new placeholder pages
const PaymentsPage = React.lazy(() => import("./pages/PaymentsPage"));
const AccountSettingsPage = React.lazy(
  () => import("./pages/AccountSettingsPage")
);
const BecomeHostPage = React.lazy(() => import("./pages/BecomeHostPage"));
const ContactPage = React.lazy(() => import("./pages/ContactPage"));
const FeedbackPage = React.lazy(() => import("./pages/FeedbackPage"));

// Update AuthModalState interface
interface AuthModalState {
  isOpen: boolean;
  isSignUp: boolean;
  mode?: "login" | "register" | "reset-password";
  email?: string;
}

// Layout component that provides context for filter modal and scroll state
const AppLayout = () => {
  const [isFilterModalOpen, setIsFilterModalOpen] = useState(false);
  const [headerHeight, setHeaderHeight] = useState(0);
  const [authModalState, setAuthModalState] = useState<AuthModalState>({
    isOpen: false,
    isSignUp: true,
    mode: "login",
  });
  const [activeParentCategory, setActiveParentCategory] = useState<
    string | null
  >(null);
  const [isSearchModalOpen, setIsSearchModalOpen] = useState(false);
  const [filterOptions, setFilterOptions] = useState<FilterOptions>({
    priceRange: [50, 1000],
  });
  const [selectedCategory, setSelectedCategory] = useState<string | null>(
    new URLSearchParams(window.location.search).get("category")
  );
  const [showDeletedBanner, setShowDeletedBanner] = useState(false);
  const location = useLocation();
  const navigate = useNavigate();

  const isMobile = useMediaQuery("(max-width: 768px)");
  const [currentTab, setCurrentTab] = useState<
    "explore" | "wishlists" | "trips" | "inbox" | "profile"
  >("explore");

  // Check if user is logged in for protected routes
  useEffect(() => {
    const protectedRoutes = [
      "/profile",
      "/bookings",
      "/wishlists",
      "/messages",
      "/notifications",
      "/host/dashboard",
      "/manage-listings",
      "/payment-setup",
      "/create-listing",
      "/edit-listing",
    ];

    const checkAuth = async () => {
      const {
        data: { session },
      } = await supabase.auth.getSession();

      // Check if current path is a protected route and user is not logged in
      if (
        protectedRoutes.some((route) => location.pathname.startsWith(route)) &&
        !session
      ) {
        setAuthModalState({ isOpen: true, isSignUp: false });
      }
    };

    checkAuth();
  }, [location.pathname]);

  // Track header fixed state to adjust content padding
  useEffect(() => {
    const updateHeaderState = () => {
      const scrollY = window.scrollY;
      document.body.classList.toggle("header-is-fixed", scrollY > 0);
    };

    // Update on mount
    updateHeaderState();

    // Update on scroll with passive listener for better performance
    window.addEventListener("scroll", updateHeaderState, { passive: true });

    return () => {
      window.removeEventListener("scroll", updateHeaderState);
      document.body.classList.remove("header-is-fixed");
    };
  }, []);

  // Add or remove landing-page class on body based on route
  useEffect(() => {
    const isLandingPage = location.pathname === "/";
    document.body.classList.toggle("landing-page", isLandingPage);

    return () => {
      document.body.classList.remove("landing-page");
    };
  }, [location.pathname]);

  // Update current tab based on route
  useEffect(() => {
    const path = location.pathname;
    if (path.includes("/wishlists")) setCurrentTab("wishlists");
    else if (path.includes("/bookings")) setCurrentTab("trips");
    else if (path.includes("/messages")) setCurrentTab("inbox");
    else if (path.includes("/profile")) setCurrentTab("profile");
    else setCurrentTab("explore");
  }, [location.pathname]);

  // Listen for auth modal open requests
  useEffect(() => {
    const handleOpenAuthModal = (event: CustomEvent) => {
      const isSignUp = event.detail?.isSignUp || false;
      setAuthModalState({ isOpen: true, isSignUp });
    };

    // Add event listener
    document.addEventListener(
      "openAuthModal",
      handleOpenAuthModal as EventListener
    );

    // Clean up
    return () => {
      document.removeEventListener(
        "openAuthModal",
        handleOpenAuthModal as EventListener
      );
    };
  }, []);

  // Determine if we are on the listing wizard page
  const isListingWizardPage = isOnListingWizardPage();

  const handleFilterChange = (filters: FilterOptions) => {
    console.log("App level: Applying filters", filters);

    // Check if we have a valid price range
    if (
      !filters ||
      !Array.isArray(filters.priceRange) ||
      filters.priceRange.length !== 2
    ) {
      console.warn("Invalid filters format:", filters);
      return;
    }

    // Ensure both values are numbers
    const minPrice =
      typeof filters.priceRange[0] === "number"
        ? filters.priceRange[0]
        : parseInt(filters.priceRange[0]);
    const maxPrice =
      typeof filters.priceRange[1] === "number"
        ? filters.priceRange[1]
        : parseInt(filters.priceRange[1]);

    if (isNaN(minPrice) || isNaN(maxPrice)) {
      console.warn("Invalid price range values:", filters.priceRange);
      return;
    }

    console.log(`App level: Setting filters`, filters);

    // Update app state
    setFilterOptions(filters);

    // Update URL with filter parameters
    const searchParams = new URLSearchParams(location.search);

    // Set price range
    searchParams.set("minPrice", minPrice.toString());
    searchParams.set("maxPrice", maxPrice.toString());

    // Set sort option
    if (filters.sortBy) {
      console.log(`App level: Setting sort parameter to ${filters.sortBy}`);
      searchParams.set("sort", filters.sortBy);
    } else {
      console.log("App level: No sort parameter to set");
      searchParams.delete("sort");
    }

    // Set bedrooms filter
    if (filters.bedrooms !== undefined && filters.bedrooms !== null) {
      searchParams.set("bedrooms", filters.bedrooms.toString());
    } else {
      searchParams.delete("bedrooms");
    }

    // Set bathrooms filter
    if (filters.bathrooms !== undefined && filters.bathrooms !== null) {
      searchParams.set("bathrooms", filters.bathrooms.toString());
    } else {
      searchParams.delete("bathrooms");
    }

    // Set min guests filter
    if (filters.minGuests !== undefined && filters.minGuests !== null) {
      searchParams.set("guests", filters.minGuests.toString());
    } else {
      searchParams.delete("guests");
    }

    // Set amenities filter
    if (filters.amenities && filters.amenities.length > 0) {
      searchParams.set("amenities", filters.amenities.join(","));
    } else {
      searchParams.delete("amenities");
    }

    // Set boolean filters
    if (filters.allowPets) {
      searchParams.set("pets", "true");
    } else {
      searchParams.delete("pets");
    }

    if (filters.instantBook) {
      searchParams.set("instant", "true");
    } else {
      searchParams.delete("instant");
    }

    // Use the paramString directly instead of creating a URL that might be cleaned
    const paramString = searchParams.toString();
    console.log(`App level: Updating URL with parameters: ?${paramString}`);
    navigate(`?${paramString}`);
  };

  // Update AppLayout to handle page initialization
  useEffect(() => {
    // Create a function to capture the direct page load state
    const captureInitialUrl = () => {
      // Store initial URL parameters to ensure they're preserved
      const initialParams = new URLSearchParams(window.location.search);
      if (initialParams.toString()) {
        console.log(
          "📌 Direct page load detected with parameters:",
          initialParams.toString()
        );

        // Set any relevant state based on URL parameters
        const categoryParam = initialParams.get("category");
        if (categoryParam) {
          setSelectedCategory(categoryParam);
        }

        // Make sure we preserve the URL parameters on initial load
        if (
          window.location.search &&
          window.location.search !== `?${initialParams.toString()}`
        ) {
          window.history.replaceState(null, "", `?${initialParams.toString()}`);
        }
      }
    };

    // Run on component mount to capture the initial state
    captureInitialUrl();
  }, []);

  // Check for deleted profile parameter
  useEffect(() => {
    const urlParams = new URLSearchParams(location.search);
    if (urlParams.get("deleted") === "true") {
      setShowDeletedBanner(true);
      // Remove the parameter from URL
      urlParams.delete("deleted");
      const newSearch = urlParams.toString();
      navigate(location.pathname + (newSearch ? `?${newSearch}` : ""), {
        replace: true,
      });

      // Hide banner after 10 seconds
      setTimeout(() => {
        setShowDeletedBanner(false);
      }, 10000);
    }
  }, [location.search, navigate, location.pathname]);

  // Update URL handling for password reset
  useEffect(() => {
    const handlePasswordRecovery = async () => {
      const {
        data: { session },
      } = await supabase.auth.getSession();

      // Check if we're in a recovery flow by checking URL parameters
      const params = new URL(window.location.href).searchParams;
      const isRecoveryFlow = params.get("type") === "recovery";

      if (isRecoveryFlow && session?.user?.email) {
        // Open auth modal in reset-password mode
        setAuthModalState({
          isOpen: true,
          isSignUp: false,
          mode: "reset-password",
          email: session.user.email,
        });

        // Clean up URL
        params.delete("type");
        window.history.replaceState(
          {},
          "",
          `${window.location.pathname}${
            params.toString() ? `?${params.toString()}` : ""
          }`
        );
      }
    };

    handlePasswordRecovery();
  }, [location.pathname]); // Run when path changes

  return (
    <div className="min-h-screen flex flex-col">
      <PageTitle title="Home" />
      <AppInitializer />

      {/* Only show Header if not on listing wizard */}
      {!isListingWizardPage && (
        <Header
          selectedCategory={selectedCategory}
          setSelectedCategory={setSelectedCategory}
          activeParentCategory={activeParentCategory}
          setActiveParentCategory={setActiveParentCategory}
          onOpenFilters={() => setIsFilterModalOpen(true)}
          onSearchModalOpen={setIsSearchModalOpen}
        />
      )}

      {/* Success banner for deleted profile */}
      {showDeletedBanner && (
        <div
          className="bg-green-100 border border-green-400 text-green-700 px-4 py-3 relative"
          role="alert"
        >
          <div className="flex items-center justify-between">
            <div className="flex items-center">
              <svg
                className="w-5 h-5 mr-2"
                fill="currentColor"
                viewBox="0 0 20 20"
              >
                <path
                  fillRule="evenodd"
                  d="M10 18a8 8 0 100-16 8 8 0 000 16zm3.707-9.293a1 1 0 00-1.414-1.414L9 10.586 7.707 9.293a1 1 0 00-1.414 1.414l2 2a1 1 0 001.414 0l4-4z"
                  clipRule="evenodd"
                />
              </svg>
              <span className="font-medium">
                Tu perfil ha sido eliminado completamente.
              </span>
            </div>
            <button
              onClick={() => setShowDeletedBanner(false)}
              className="text-green-700 hover:text-green-900"
            >
              <svg className="w-4 h-4" fill="currentColor" viewBox="0 0 20 20">
                <path
                  fillRule="evenodd"
                  d="M4.293 4.293a1 1 0 011.414 0L10 8.586l4.293-4.293a1 1 0 111.414 1.414L11.414 10l4.293 4.293a1 1 0 01-1.414 1.414L10 11.414l-4.293 4.293a1 1 0 01-1.414-1.414L8.586 10 4.293 5.707a1 1 0 010-1.414z"
                  clipRule="evenodd"
                />
              </svg>
            </button>
          </div>
        </div>
      )}

      {/* Main content */}
      <main className={cn("flex-1")}>
        <Outlet
          context={{
            isFilterModalOpen,
            setIsFilterModalOpen,
            headerHeight,
            filterOptions,
            setFilterOptions,
          }}
        />
      </main>

      {/* Filter Modal */}
      <NewFilterModal
        isOpen={isFilterModalOpen}
        onClose={() => setIsFilterModalOpen(false)}
        onApplyFilters={handleFilterChange}
      />

      {/* Render Footer only when not on Listing Wizard pages and not on mobile */}
      {!isListingWizardPage && !isMobile && <Footer />}

      <AuthModal
        isOpen={authModalState.isOpen}
        mode={authModalState.mode}
        email={authModalState.email}
        onClose={() => {
          setAuthModalState({ isOpen: false, isSignUp: true, mode: "login" });
        }}
      />
      {isMobile &&
        !location.pathname.startsWith("/property/") &&
        !(
          location.pathname.startsWith("/messages/") &&
          location.pathname.split("/").length > 2
        ) && (
          <MobileNavBar
            currentTab={currentTab}
            isSearchModalOpen={isSearchModalOpen}
          />
        )}
    </div>
  );
};

// Temporary test component for Supabase connectivity
const SupabaseTest = () => {
  const [status, setStatus] = useState("Checking connection...");
  const [error, setError] = useState<string | null>(null);
  const [user, setUser] = useState<{ id: string; email: string } | null>(null);

  useEffect(() => {
    const checkConnection = async () => {
      try {
        // Test simple query
        const { data, error } = await supabase
          .from("listings")
          .select("id")
          .limit(1);

        if (error) {
          setStatus("Connection failed");
          setError(error.message);
          return;
        }

        setStatus(`Connection successful! Found ${data.length} listings`);

        // Check auth
        const { data: userData } = await supabase.auth.getUser();
        if (userData?.user) {
          setUser(userData.user);
        }
      } catch (err) {
        setStatus("Connection error");
        setError(err instanceof Error ? err.message : "Unknown error");
      }
    };

    checkConnection();
  }, []);

  return (
    <div className="p-8 max-w-md mx-auto bg-white rounded-lg shadow-md my-10">
      <h2 className="text-2xl font-bold mb-4">Supabase Connection Test</h2>
      <div className="mb-4">
        <div
          className={`text-lg font-semibold ${
            status.includes("successful")
              ? "text-green-600"
              : status.includes("failed") || status.includes("error")
              ? "text-red-600"
              : "text-blue-600"
          }`}
        >
          Status: {status}
        </div>
        {error && (
          <div className="mt-2 p-3 bg-red-50 border border-red-200 rounded text-red-700">
            <p className="font-semibold">Error:</p>
            <p className="text-sm break-all">{error}</p>
          </div>
        )}
      </div>
      {user && (
        <div className="mt-4 p-3 bg-blue-50 border border-blue-200 rounded">
          <p className="font-semibold">Logged in as:</p>
          <p>{user.email}</p>
          <p className="text-xs text-gray-600">User ID: {user.id}</p>
        </div>
      )}
      <div className="mt-6">
        <Link to="/" className="text-blue-600 hover:underline">
          Back to Home
        </Link>
      </div>
    </div>
  );
};

// Add this utility function to handle URL parsing
const normalizeRouting = () => {
  // When using BrowserRouter, we don't need to worry about hash routing
  // Just handle query params

  // This function can still be used to clean up other URL issues
  // but the hash routing specific logic is no longer needed

  return false;
};

function App() {
  const [isAppReady, setIsAppReady] = useState(false);

  // Log restored session for debugging purposes
  useEffect(() => {
    supabase.auth.getSession().then(({ data: { session } }) => {
      console.log("Restored session:", session);
    });
  }, []);

  // Handle tab focus to check session validity
  useEffect(() => {
    let previouslyHadSession = false;

    // Check if user initially has a session
    supabase.auth.getSession().then(({ data: { session } }) => {
      previouslyHadSession = !!session;
    });

    const handleFocus = async () => {
      const { data } = await supabase.auth.getSession();

      // Only reload if user previously had a session but now it's gone
      if (previouslyHadSession && !data.session) {
        console.log("Session lost on tab focus, reloading app...");
        window.location.reload();
      } else if (data.session) {
        // Update the session tracking variable
        previouslyHadSession = true;
        console.log("Session valid on tab focus:", data.session.user.email);
      }
    };

    window.addEventListener("focus", handleFocus);
    return () => {
      window.removeEventListener("focus", handleFocus);
    };
  }, []);

  // Set app as ready after a short delay to ensure proper initialization
  useEffect(() => {
    const timer = setTimeout(() => {
      setIsAppReady(true);
      document.documentElement.classList.add("app-ready");

      // Remove duplicate headers - function to be reused
      const removeDuplicateHeaders = () => {
        const headers = document.querySelectorAll("header");
        if (headers.length > 1) {
          // Keep only the one with mainHeader ID or the first one if mainHeader is not found
          const mainHeader = document.getElementById("mainHeader");

          // Create an array from headers
          const headersArray = Array.from(headers);

          if (mainHeader) {
            // Keep main header, safely remove others
            headersArray.forEach((header) => {
              if (header.id !== "mainHeader" && header.parentNode) {
                try {
                  header.parentNode.removeChild(header);
                } catch {
                  // Silently ignore errors
                }
              }
            });
          } else {
            // If main header not found, just keep first one and remove others safely
            for (let i = 1; i < headersArray.length; i++) {
              const header = headersArray[i];
              if (header.parentNode) {
                try {
                  header.parentNode.removeChild(header);
                } catch {
                  // Silently ignore errors
                }
              }
            }
          }

          // Log more informative message
          if (process.env.NODE_ENV === "development") {
            console.info("Handled duplicate headers");
          }
        }
      };

      // Initial cleanup after a short delay
      setTimeout(removeDuplicateHeaders, 100);

      // Create a MutationObserver to detect DOM changes
      const observer = new MutationObserver(() => {
        // Simple approach - just call the function directly
        removeDuplicateHeaders();
      });

      // Start observing the document with the configured parameters
      observer.observe(document.body, {
        childList: true,
        subtree: true,
      });

      return () => {
        // Disconnect the observer when component unmounts
        observer.disconnect();
      };
    }, 100);

    return () => clearTimeout(timer);
  }, []);

  // Add idle detection and refresh handler
  useEffect(() => {
    let lastActiveTime = Date.now();
    const idleThreshold = 30 * 60 * 1000; // 30 minutes in milliseconds

    const handleVisibilityChange = () => {
      if (document.visibilityState === "visible") {
        const currentTime = Date.now();
        const idleTime = currentTime - lastActiveTime;

        if (idleTime > idleThreshold) {
          console.log("App was idle for too long, refreshing...");
          window.location.reload();
        }
      }

      lastActiveTime = Date.now();
    };

    const handleUserActivity = () => {
      lastActiveTime = Date.now();
    };

    // Listen for visibility changes when tab becomes visible again
    document.addEventListener("visibilitychange", handleVisibilityChange);

    // Also track user activity while the tab is open
    document.addEventListener("click", handleUserActivity);
    document.addEventListener("keypress", handleUserActivity);
    document.addEventListener("scroll", handleUserActivity);
    document.addEventListener("mousemove", handleUserActivity);

    return () => {
      document.removeEventListener("visibilitychange", handleVisibilityChange);
      document.removeEventListener("click", handleUserActivity);
      document.removeEventListener("keypress", handleUserActivity);
      document.removeEventListener("scroll", handleUserActivity);
      document.removeEventListener("mousemove", handleUserActivity);
    };
  }, []);

  // Call this inside the main App component
  useEffect(() => {
    // Normalize URL structure if necessary
    normalizeRouting();

    // Rest of your initialization code...
  }, []);

  // Initialize Supabase on app load
  useEffect(() => {
    initSupabase();

    // Initialize push notifications
    initializePushNotifications()
      .then((initialized) => {
        if (initialized) {
          console.log("Push notifications initialized");
        }
      })
      .catch((error) => {
        console.error("Failed to initialize push notifications:", error);
      });
  }, []);

  return (
    <>
      <Toaster
        position="top-center"
        toastOptions={{
          duration: 4000,
          style: {
            background: "#333",
            color: "#fff",
            borderRadius: "12px",
          },
          success: {
            iconTheme: {
              primary: "#22c55e",
              secondary: "#fff",
            },
          },
          error: {
            iconTheme: {
              primary: "#ef4444",
              secondary: "#fff",
            },
          },
        }}
      />
      {/* Add custom scrollbar styles */}
      <style>{`
        /* Custom scrollbar styles for dropdowns */
        .custom-scrollbar::-webkit-scrollbar {
          width: 6px;
        }
        
        .custom-scrollbar::-webkit-scrollbar-track {
          background-color: transparent;
        }
        
        .custom-scrollbar::-webkit-scrollbar-thumb {
          background-color: rgba(0, 0, 0, 0.2);
          border-radius: 3px;
        }
      `}</style>

      <div className={isAppReady ? "app-initialized" : "app-initializing"}>
        <Router
          future={{ v7_startTransition: true, v7_relativeSplatPath: true }}
        >
          <AuthProvider>
            <Suspense fallback={<LoadingDots />}>
              <Routes>
                <Route path="/" element={<Outlet />}>
                  <Route element={<AppLayout />}>
                    <Route path="/" element={<ListingPage />} />
                    <Route
                      path="/property/:id"
                      element={<PropertyDetailPage />}
                    />
                    <Route
                      path="/create-listing"
                      element={
                        <ProtectedRoute>
                          <CreateListingPage />
                        </ProtectedRoute>
                      }
                    />
                    <Route
                      path="/edit-listing/:id"
                      element={
                        <ProtectedRoute>
                          <EditListingPage />
                        </ProtectedRoute>
                      }
                    />
                    <Route
                      path="/manage-listings"
                      element={
                        <ProtectedRoute>
                          <ManageListingsPage />
                        </ProtectedRoute>
                      }
                    />
                    <Route
                      path="/manage-listings/:id/availability"
                      element={
                        <ProtectedRoute>
                          <PropertyAvailabilityPage />
                        </ProtectedRoute>
                      }
                    />
                    <Route
                      path="/host/dashboard"
                      element={
                        <ProtectedRoute>
                          <HostDashboardRoute type="dashboard" />
                        </ProtectedRoute>
                      }
                    />
                    <Route
                      path="/host"
                      element={<Navigate to="/host/dashboard" replace />}
                    />
                    <Route
                      path="/host/calendar"
                      element={
                        <ProtectedRoute>
                          <HostDashboardRoute type="calendar" />
                        </ProtectedRoute>
                      }
                    />
                    <Route path="/host/:id" element={<HostProfilePage />} />
                    <Route
                      path="/profile"
                      element={
                        <ProtectedRoute>
                          <ProfilePage />
                        </ProtectedRoute>
                      }
                    />
                    <Route
                      path="/payments"
                      element={
                        <ProtectedRoute>
                          <PaymentsPage />
                        </ProtectedRoute>
                      }
                    />
                    <Route
                      path="/account/settings"
                      element={
                        <ProtectedRoute>
                          <AccountSettingsPage />
                        </ProtectedRoute>
                      }
                    />
                    <Route
                      path="/become-a-host"
                      element={
                        <ProtectedRoute>
                          <BecomeHostPage />
                        </ProtectedRoute>
                      }
                    />
                    <Route
                      path="/contact"
                      element={
                        <ProtectedRoute>
                          <ContactPage />
                        </ProtectedRoute>
                      }
                    />
                    <Route path="/feedback" element={<FeedbackPage />} />
                    <Route path="/help" element={<HelpCenterPage />} />
                    <Route path="/help/account" element={<AccountHelpPage />} />
                    <Route
                      path="/help/bookings"
                      element={<BookingsHelpPage />}
                    />
                    <Route
                      path="/help/payments"
                      element={<PaymentsHelpPage />}
                    />
                    <Route path="/help/safety" element={<SafetyHelpPage />} />
                    <Route
                      path="/help/communication"
                      element={<CommunicationHelpPage />}
                    />
                    <Route
                      path="/payment-setup"
                      element={
                        <ProtectedRoute>
                          <PaymentSetupPage />
                        </ProtectedRoute>
                      }
                    />
                    <Route
                      path="/stripe-setup"
                      element={
                        <ProtectedRoute>
                          <StripeSetupPage />
                        </ProtectedRoute>
                      }
                    />
                    <Route
                      path="/bookings"
                      element={
                        <ProtectedRoute>
                          <BookingsPage />
                        </ProtectedRoute>
                      }
                    />
                    <Route
                      path="/wishlists"
                      element={
                        <ProtectedRoute>
                          <WishlistsPage />
                        </ProtectedRoute>
                      }
                    />
                    <Route
                      path="/messages"
                      element={
                        <ProtectedRoute>
                          <MessagesPage />
                        </ProtectedRoute>
                      }
                    />
                    <Route
                      path="/notifications"
                      element={
                        <ProtectedRoute>
                          <NotificationsPage />
                        </ProtectedRoute>
                      }
                    />
                    <Route
                      path="/messages/:conversationId"
                      element={
                        <ProtectedRoute>
                          <MessagesPage />
                        </ProtectedRoute>
                      }
                    />
                    <Route
                      path="/admin"
                      element={
                        <ProtectedRoute>
                          <AdminPage />
                        </ProtectedRoute>
                      }
                    />
                    <Route
                      path="/admin/dashboard"
                      element={
                        <ProtectedRoute>
                          <AdminDashboardPage />
                        </ProtectedRoute>
                      }
                    />
                    <Route
                      path="/admin/users"
                      element={
                        <ProtectedRoute>
                          <AdminUsersPage />
                        </ProtectedRoute>
                      }
                    />
                    <Route
                      path="/admin/listings"
                      element={
                        <ProtectedRoute>
                          <AdminListingsPage />
                        </ProtectedRoute>
                      }
                    />
                    <Route
                      path="/admin/bookings"
                      element={
                        <ProtectedRoute>
                          <AdminBookingsPage />
                        </ProtectedRoute>
                      }
                    />
                    <Route
                      path="/admin/claims"
                      element={
                        <ProtectedRoute>
                          <AdminClaimsPage />
                        </ProtectedRoute>
                      }
                    />
                    <Route
                      path="/admin/bootstrap"
                      element={<AdminBootstrapPage />}
                    />
                    <Route
                      path="/admin/revenue"
                      element={<AdminRevenuePage />}
                    />
                    <Route
                      path="/admin/settings"
                      element={<AdminSettingsPage />}
                    />
                    <Route path="/admin/emails" element={<AdminEmailsPage />} />
                    <Route
                      path="/admin/stress-test"
                      element={<AdminStressTestPage />}
                    />
                    <Route
                      path="/admin/booking-stress-test"
                      element={<AdminBookingStressTestPage />}
                    />
                    <Route
                      path="/admin/message-reports"
                      element={<AdminMessageReportsPage />}
                    />
                    <Route path="/supabase-test" element={<SupabaseTest />} />
                    <Route path="/checkout" element={<CheckoutPage />} />
                    <Route path="/privacy" element={<PrivacyPolicyPage />} />
                    <Route
                      path="/notifications/settings"
                      element={
                        <ProtectedRoute>
                          <NotificationSettingsPage />
                        </ProtectedRoute>
                      }
                    />
                    <Route path="/terms" element={<TermsOfServicePage />} />
                  </Route>
                </Route>
              </Routes>
            </Suspense>
          </AuthProvider>
        </Router>
      </div>
    </>
  );
}

export default App;
